@@ -34,22 +34,26 @@
 #' @examples
 #' # Example 01: OS monitoring guideline retrospectively applied to Motivating Example 1
 #' # with delta null = 1.3, delta alt = 0.80, gamma_FA = 0.025 and  beta_PA = 0.10.
-#' bounds(events=c(60, 89, 110, 131, 178),
-#'         power_int=0.9,  # beta_PA
-#'         falsepos=0.025, # gamma_FA
-#'         hr_null = 1.3,  # delta_null
-#'         hr_alt = 0.8,   # delta_alt
-#'         rand_ratio = 1, # rand_ratio
-#'         hr_marg_benefit = NULL)
+#' bounds(
+#'   events = c(60, 89, 110, 131, 178),
+#'   power_int = 0.9, # beta_PA
+#'   falsepos = 0.025, # gamma_FA
+#'   hr_null = 1.3, # delta_null
+#'   hr_alt = 0.8, # delta_alt
+#'   rand_ratio = 1, # rand_ratio
+#'   hr_marg_benefit = NULL
+#' )
 #' # Example 02: OS monitoring guideline applied to Motivating Example 2
 #' # with delta null = 4/3, delta alt = 0.7, gamma_FA = 0.20 and beta_PA = 0.1.
-#' bounds(events=c(60, 89, 110, 131, 178),
-#'        power_int=0.9,  # beta_PA
-#'        falsepos=0.025, # gamma_FA
-#'        hr_null = 1.3,  # delta_null
-#'        hr_alt = 0.8,   # delta_alt
-#'        rand_ratio = 1, # rand_ratio
-#'        hr_marg_benefit = 0.95)
+#' bounds(
+#'   events = c(60, 89, 110, 131, 178),
+#'   power_int = 0.9, # beta_PA
+#'   falsepos = 0.025, # gamma_FA
+#'   hr_null = 1.3, # delta_null
+#'   hr_alt = 0.8, # delta_alt
+#'   rand_ratio = 1, # rand_ratio
+#'   hr_marg_benefit = 0.95
+#' )
 bounds <- function(events,
                    # OS events at each analysis
                    power_int = 0.9,
@@ -64,8 +68,7 @@ bounds <- function(events,
                    # for every patient randomized to control, rand_ratio patients are allocated to experimental intervention
                    hr_marg_benefit = NULL
                    # evaluate probability of meeting positivity thresholds under a second plausible beneficial effect of treatment on OS (HR = hr_marg_benefit)
-                   ) {
-
+) {
   # Log scale
   lhr_null <- log(hr_null)
   lhr_alt <- log(hr_alt)
@@ -73,7 +76,7 @@ bounds <- function(events,
   # Init variables
   nstage <- length(events) # total number of analyses planned
   info <-
-    rand_ratio*events / ((rand_ratio + 1)^2) # Fisher's information for log-HR at each analysis
+    rand_ratio * events / ((rand_ratio + 1)^2) # Fisher's information for log-HR at each analysis
   se <-
     sqrt(1 / info) # asymptotic standard error for log-HR at each analysis
 
@@ -100,34 +103,36 @@ bounds <- function(events,
   post_pos <- calc_posterior(lhr_pos, lhr_null, events)
   pred_pos <- calc_predictive(lhr_pos, events)
 
-  summary <- data.frame('Deaths' = events)
+  summary <- data.frame("Deaths" = events)
 
   # OS HR thresholds for positivity
-  summary$'OS HR threshold for positivity' <- round(exp(lhr_pos), 3)
+  summary$"OS HR threshold for positivity" <- round(exp(lhr_pos), 3)
 
   # One sided false positive error_rate at each analysis
-  summary$'One-sided false positive error rate' <- round(falsepos_all, 3)
+  summary$"One-sided false positive error rate" <- round(falsepos_all, 3)
 
   # Level of 2-sided CI needed to rule out δnull at given analysis (%)
-  summary$'Level of 2-sided CI needed to rule out delta null' <- round(pmax(0, CI_level_monit_null), 0)
+  summary$"Level of 2-sided CI needed to rule out delta null" <- round(pmax(0, CI_level_monit_null), 0)
 
   # Probability of meeting positivity threshold under plausible OS benefit
-  summary$'Probability of meeting positivity threshold under delta alt' <- round(power_all, 3)
+  summary$"Probability of meeting positivity threshold under delta alt" <- round(power_all, 3)
 
   # Pr(true OS HR >= detrimental OS HR | current data)
-  summary$'Posterior probability the true OS HR exceeds delta null given the data' <- round(post_pos, 3)
-  summary$'Predictive probability the OS HR estimate at Final Analysis does not exceed the positivity threshold' <- c(round(pred_pos * 100, 3), NA)
+  summary$"Posterior probability the true OS HR exceeds delta null given the data" <- round(post_pos, 3)
+  summary$"Predictive probability the OS HR estimate at Final Analysis does not exceed the positivity threshold" <- c(round(pred_pos * 100, 3), NA)
 
   if (!is.null(hr_marg_benefit)) {
     # calculate the probability of meeting positivity thresholds under lhr_marg_benefit
-    summary$'Probability of meeting positivity threshold under incremental benefit' <-
-      round(meeting_probs(
-        summary = summary,
-        lhr_pos = lhr_pos,
-        lhr_target = log(hr_marg_benefit),
-        rand_ratio = rand_ratio
-      ),
-      3)
+    summary$"Probability of meeting positivity threshold under incremental benefit" <-
+      round(
+        meeting_probs(
+          summary = summary,
+          lhr_pos = lhr_pos,
+          lhr_target = log(hr_marg_benefit),
+          rand_ratio = rand_ratio
+        ),
+        3
+      )
   }
 
   return(list(
@@ -136,5 +141,4 @@ bounds <- function(events,
     lhr_pos = lhr_pos,
     summary = summary
   ))
-
 }
